wisetrack library
Classes
- ScreenDeduplicator
- WiseTrack
- WiseTrackJsEvaluator
- WiseTrackWebBridge
- WTAndroidConfig
- WTAndroidStore
- Represents the various Android store names supported in the application.
- WTEvent
- A class representing an event that can be tracked within the WiseTrack SDK.
- WTInitialConfig
- Configuration class for initializing the WiseTrack SDK.
- WTIOSConfig
- WTIOSStore
- Represents the various iOS stores supported in the application.
- A NavigatorObserver that automatically tracks screen views via WiseTrack.
- WTParam
- Represents a parameter value for an event/screen in the WiseTrack analytics system.
- WTScreen
- Represents a screen view event for WiseTrack analytics.
- WTScreenDataProvider
- Custom screen data returned by a WTScreenTrackingConfig.screenDataProvider callback.
- WTScreenTrackingConfig
- Configuration for automatic screen tracking via WTNavigatorObserver.
Enums
- RevenueCurrency
- WTEventType
- Represents different types of events that can be tracked in WiseTrack SDK.
- WTLogLevel
- Represents the log levels used for logging events within the application.
- WTScreenType
- The visual presentation style of a tracked screen.
- WTUserEnvironment
- Public enumeration representing different User environments.
Mixins
-
WTScreenTrackMixin<
T extends StatefulWidget> - Mixin for manual screen tracking on individual widgets.
Extensions
Typedefs
-
JSMessageCallback
= Future<
void> Function(String message)